Acknowledgements
-----------------
``binarymap`` is written by `the Bloom lab <https://research.fhcrc.org/bloom/en.html>`_.

See https://github.com/jbloomlab/binarymap/graphs/contributors for the full list of contributors.
